#  Interactive Gibson Environment
Large Scale Virtualized Interactive Environment for Learning Robot Manipulation and Navigation

Interactive Gibson is a fast simulator and a dataset for indoor navigation and manipulation. It was first released in June 2019. It allows for complicated interactions between the agent and the environment, such as picking up and placing objects, or opening doors and cabinets. This environment opens up new venues for jointly training base and arm policies, allowing researchers to explore the synergy between manipulation and navigation.


#### Paper
If you use Interactive Gibson Simulator or Interactive Gibson assets, please consider citing the following paper:

```
@techreport{xiagibson2019,
           title = {Gibson Env V2: Embodied Simulation Environments for Interactive Navigation},
           author = {Xia, Fei and Li, Chengshu and Chen, Kevin and Shen, William B and Mart{\'i}n-Mart{\'i}n, Roberto and Hirose, Noriaki and Zamir, Amir R and Fei-Fei, Li and Savarese, Silvio},
           group = {Stanford Vision and Learning Group},
           year = {2019},
           institution = {Stanford University},
           month = {6},
}
```


Release
=================
**This is the gibson2 0.0.1 release. Bug reports, suggestions for improvement, as well as community developments are encouraged and appreciated.** [change log file](misc/CHANGELOG.md).  

**Support for [Gibson v1](http://github.com/StanfordVL/GibsonEnv/) will be moved to this repo**.

Documentation
=================
- [Interactive Gibson Environment Documentation](http://svl.stanford.edu/gibson2/docs/).

Dataset Download
=================
- [Download Gibson V2 dataset](https://forms.gle/q5Ygkw3ijxD5WC5U8).
